@@ -35,6 +35,25 @@
 
 G_BEGIN_DECLS
 
+/**
+ * GnomeVFSMakeURIDirs:
+ * @GNOME_VFS_MAKE_URI_DIR_NONE: Don't check any directory
+ * @GNOME_VFS_MAKE_URI_DIR_HOMEDIR: Check the home directory
+ * @GNOME_VFS_MAKE_URI_DIR_CURRENT: Check the current direcotry
+ * 
+ * Flags that can be passed to gnome_vfs_make_uri_from_input_with_dirs().
+ * If the given input might be a relative path it checks for existence of the file
+ * in the directory specified by this flag.
+ * If both flags are passed the current directory is checked first.
+ * 
+ **/
+
+typedef enum {
+	GNOME_VFS_MAKE_URI_DIR_NONE = 0,
+	GNOME_VFS_MAKE_URI_DIR_HOMEDIR = 1 << 0,
+	GNOME_VFS_MAKE_URI_DIR_CURRENT = 1 << 1
+} GnomeVFSMakeURIDirs;
+
 /* Makes a human-readable string. */
 char *gnome_vfs_format_file_size_for_display (GnomeVFSFileSize  size);
 
@@ -142,14 +161,28 @@ GnomeVFSResult  gnome_vfs_read_entire_file (const char *uri,
 					    int *file_size,
 					    char **file_contents);
 
-char * gnome_vfs_format_uri_for_display (const char *uri);
-char * gnome_vfs_make_uri_from_input (const char *uri);
-char * gnome_vfs_make_uri_canonical_strip_fragment (const char *uri);
-gboolean gnome_vfs_uris_match (const char *uri_1, const char *uri_2);
-char * gnome_vfs_get_uri_scheme (const char *uri);
-char * gnome_vfs_make_uri_from_shell_arg (const char *uri);
+char *   gnome_vfs_format_uri_for_display            (const char          *uri);
+char *   gnome_vfs_make_uri_from_input               (const char     *location);
+char *   gnome_vfs_make_uri_from_input_with_trailing_ws 
+                                                     (const char     *location);
+char *   gnome_vfs_make_uri_from_input_with_dirs     (const char     *location,
+						      GnomeVFSMakeURIDirs  dirs);
+char *   gnome_vfs_make_uri_canonical_strip_fragment (const char          *uri);
+gboolean gnome_vfs_uris_match                        (const char          *uri_1,
+						      const char          *uri_2);
+char *   gnome_vfs_get_uri_scheme                    (const char          *uri);
+char *   gnome_vfs_make_uri_from_shell_arg           (const char          *uri);
+
+
+#ifndef GNOME_VFS_DISABLE_DEPRECATED
 char * gnome_vfs_make_uri_full_from_relative (const char *base_uri,
 					      const char *relative_uri);
+#endif /* GNOME_VFS_DISABLE_DEPRECATED */
+
+GnomeVFSResult gnome_vfs_url_show                        (const char   *url);
+GnomeVFSResult gnome_vfs_url_show_with_env               (const char   *url, 
+                                                          char        **envp);
+
 
 G_END_DECLS
 
