@@ -20,7 +20,7 @@
    Boston, MA 02111-1307, USA.
 
    Authors: 
-		 John McCutchan <ttb@tentacle.dhs.org>
+		 John McCutchan <john@johnmccutchan.com>
 */
 
 #include "config.h"
@@ -28,24 +28,13 @@
 #include <time.h>
 #include <string.h>
 #include <sys/ioctl.h>
-/* Just include the local header to stop all the pain */
-#include "local_inotify.h"
-#if 0
-#ifdef HAVE_SYS_INOTIFY_H
-/* We don't actually include the libc header, because there has been
- * problems with libc versions that was built without inotify support.
- * Instead we use the local version.
- */
-#include "local_inotify.h"
-#elif defined (HAVE_LINUX_INOTIFY_H)
-#include <linux/inotify.h>
-#endif
-#endif
+#include <sys/inotify.h>
 #include <libgnomevfs/gnome-vfs-module-shared.h>
 #include <libgnomevfs/gnome-vfs-utils.h>
 #include "inotify-helper.h"
 #include "inotify-missing.h"
 #include "inotify-path.h"
+#include "inotify-diag.h"
 
 static gboolean		ih_debug_enabled = FALSE;
 #define IH_W if (ih_debug_enabled) g_warning 
@@ -95,6 +84,7 @@ ih_startup (void)
 		return FALSE;
 	}
 	im_startup (ih_not_missing_callback);
+	id_startup ();
 
 	IH_W ("started gnome-vfs inotify backend\n");
 
@@ -208,6 +198,7 @@ ih_mask_to_EventType (guint32 mask)
 	case IN_MOVED_FROM:
 	case IN_DELETE:
 	case IN_DELETE_SELF:
+	case IN_UNMOUNT:
 		return GNOME_VFS_MONITOR_EVENT_DELETED;
 	break;
 	case IN_CREATE:
@@ -218,7 +209,6 @@ ih_mask_to_EventType (guint32 mask)
 	case IN_OPEN:
 	case IN_CLOSE_WRITE:
 	case IN_CLOSE_NOWRITE:
-	case IN_UNMOUNT:
 	case IN_ACCESS:
 	case IN_IGNORED:
 	default:
